==> apache-qpid-broker-j-9.0.0-src.tar.gz: apache-qpid-broker-j-9.0.0-src/broker-core/src/test/java/org/apache/qpid/server/security/auth/manager/ScramSHA1AuthenticationManagerTest.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.security.auth.manager;

import static org.junit.Assert.fail;

import java.util.Collections;
import java.util.Map;

import org.junit.Test;

public class ScramSHA1AuthenticationManagerTest extends ManagedAuthenticationManagerTestBase
{
    @Override
    protected ConfigModelPasswordManagingAuthenticationProvider<?> createAuthManager(final Map<String, Object> attributesMap)
    {
        return new ScramSHA1AuthenticationManager(attributesMap, getBroker());
    }

    @Override
    protected boolean isPlain()
    {
        return false;
    }

    @Test
    public void testNonASCIIUser()
    {
        try
        {
            getAuthManager().createUser(getTestName() + Character.toString((char) 0xa3),
                                        "password",
                                        Collections.<String, String>emptyMap());
            fail("Expected exception when attempting to create a user with a non ascii name");
        }
        catch(IllegalArgumentException e)
        {
            // pass
        }
    }

}

==> apache-qpid-broker-j-10.0.0-src.tar.gz: apache-qpid-broker-j-10.0.0-src/broker-core/src/test/java/org/apache/qpid/server/security/auth/manager/ScramSHA1AuthenticationManagerTest.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.security.auth.manager;

import static org.junit.jupiter.api.Assertions.assertThrows;

import java.util.Map;

import org.junit.jupiter.api.Test;

public class ScramSHA1AuthenticationManagerTest extends ManagedAuthenticationManagerTestBase
{
    @Override
    protected ConfigModelPasswordManagingAuthenticationProvider<?> createAuthManager(final Map<String, Object> attributesMap)
    {
        return new ScramSHA1AuthenticationManager(attributesMap, getBroker());
    }

    @Override
    protected boolean isPlain()
    {
        return false;
    }

    @Test
    public void testNonASCIIUser()
    {
        assertThrows(IllegalArgumentException.class,
                () -> getAuthManager().createUser(getTestName() + (char) 0xa3, "password", Map.of()),
                "Expected exception when attempting to create a user with a non ascii name");
    }

}
